@@ -3,6 +3,7 @@
 from imio.helpers.interfaces import IContainerOfUnindexedElementsMarker
 from persistent.list import PersistentList
 from plone import api
+from plone.api.content import _parse_object_provides_query
 from plone.api.validation import mutually_exclusive_parameters
 from plone.app.textfield.value import RichTextValue
 from plone.behavior.interfaces import IBehavior
@@ -476,6 +477,65 @@ def uuidToObject(uuid,
     return res
 
 
+def find(context=None, depth=None, unrestricted=False, **kwargs):
+    """Same as api.content.find... but possibly unrestrictedly
+
+    :param context: Context for the search
+    :type obj: Content object
+    :param depth: How far in the content tree we want to search from context
+    :type obj: Content object
+    :param unrestricted: unrestricted flag (default=False)
+    :type bool:
+    :returns: Catalog brains
+    :rtype: List
+    """
+    query = {}
+    query.update(**kwargs)
+
+    # Save the original path to maybe restore it later.
+    orig_path = query.get('path')
+    if isinstance(orig_path, dict):
+        orig_path = orig_path.get('query')
+
+    # Passing a context or depth overrides the existing path query,
+    # for now.
+    if context or depth is not None:
+        # Make the path a dictionary, unless it already is.
+        if not isinstance(orig_path, dict):
+            query['path'] = {}
+
+    # Limit search depth
+    if depth is not None:
+        # If we don't have a context, we'll assume the portal root.
+        if context is None and not orig_path:
+            context = api.portal.get()
+        else:
+            # Restore the original path
+            query['path']['query'] = orig_path
+        query['path']['depth'] = depth
+
+    if context is not None:
+        query['path']['query'] = '/'.join(context.getPhysicalPath())
+
+    # Convert interfaces to their identifiers and also allow to query
+    # multiple values using {'query:[], 'operator':'and|or'}
+    obj_provides = query.get('object_provides', [])
+    if obj_provides:
+        query['object_provides'] = _parse_object_provides_query(obj_provides)
+
+    # Make sure we don't dump the whole catalog.
+    catalog = api.portal.get_tool('portal_catalog')
+    indexes = catalog.indexes()
+    valid_indexes = [index for index in query if index in indexes]
+    if not valid_indexes:
+        return []
+    if unrestricted:
+        # return a new list to avoid error if corresponding looped object is deleted
+        return list(catalog.unrestrictedSearchResults(**query))
+    else:
+        return catalog.searchResults(**query)
+
+
 def disable_link_integrity_checks():
     """ """
     ptool = queryUtility(IPropertiesTool)
@@ -625,18 +685,24 @@ def object_ids(context, class_names):
 
 
 def get_user_fullname(username):
-    """Get fullname without using getMemberInfo that is slow slow slow..."""
+    """Get fullname without using getMemberInfo that is slow slow slow...
+       We get it only from mutable_properties or authentic.
+       If no fullname, return username instead nothing."""
     acl_users = api.portal.get_tool('acl_users')
     storages = [acl_users.mutable_properties._storage, ]
     # if authentic is available check it first
-    if hasattr(acl_users, 'authentic'):
+    if base_hasattr(acl_users, 'authentic'):
         storages.insert(0, acl_users.authentic._useridentities_by_userid)
 
     for storage in storages:
         data = storage.get(username, None)
-        if data:
-            if hasattr(data, 'get') and data.get('fullname'):
-                return data.get('fullname')
+        if data is not None:
+            fullname = ""
+            # mutable_properties
+            if hasattr(data, 'get'):
+                fullname = data.get('fullname')
+            # authentic
             else:
-                return data._identities['authentic-agents'].data['fullname']
+                fullname = data._identities['authentic-agents'].data['fullname']
+            return fullname or username
     return username
